Every diagnostic function in the package returns an object of class
"rcdiag_result". This constructor is the single source of truth for the
result shape.
Usage
rcdiag_result(status, label, detail, data = list())Every diagnostic function in the package returns an object of class
"rcdiag_result". This constructor is the single source of truth for the
result shape.
rcdiag_result(status, label, detail, data = list())